@@ -8,7 +8,6 @@ import json
 import uuid
 import sys
 import firebase_admin
-import logging
 
 from firebase_admin import auth
 
@@ -28,7 +27,6 @@ else:
     )
     firebase = firebase_admin.initialize_app(firebase_credentials)
 
-logger = logging.getLogger()
 
 class TonicAuthentication():
     www_authenticate_realm = 'api'
@@ -39,12 +37,10 @@ class TonicAuthentication():
 
         Hide some test client ickyness where the header can be unicode.
         """
-        logger.info(f"Request META items: {request.META.items()}")
         auth = request.META.get('HTTP_AUTHORIZATION', b'')
         if isinstance(auth, str):
             # Work around django test client oddness
             auth = auth.encode(HTTP_HEADER_ENCODING)
-        logger.info(f"AUTH HEADER for this request is {auth}.")
         return auth
 
     def authenticate(self, request):
@@ -54,7 +50,6 @@ class TonicAuthentication():
         """
         authorization_header = self.get_authorization_header(request)
         if settings_auth["ALLOW_ANONYMOUS_REQUESTS"] and not authorization_header:
-            logger.info(f"No AUTH HEADER found for request {request}. ANONYMOUS MODE ACTIVE.")
             return (None, None)
         """
         Returns a tuple of len(2) of `User` and the decoded firebase token if
