@@ -29,6 +29,12 @@ class LocaleMiddleware(object):
                 'Incorrect Accept-Language. Example: Accept-Language: pt-PT'
             )
 
+        # V2.13.6: Temporary fix
+        if accept_language not in ['el-GR', 'en-GB', 'de-DE', 'it-IT', 'fr-FR', 'es-ES', 'pt-PT']:
+            logger.warning(f'This accept language does not exist. Accept Language: {accept_language};')
+            accept_language = 'pt-PT'
+        # End of logic
+
         activate(accept_language)
 
         request.locale = accept_language
