@@ -1,10 +1,11 @@
 import datetime
+import json
 
 from django.db import models
 from django.core.validators import MaxValueValidator, MinValueValidator
-from django.contrib.postgres.fields import JSONField
 
 from helpers.validators import locale_regex
+from helpers.models_schema_fields import client_schema
 
 class Base(models.Model):
     INVISIBLE = 0
@@ -19,7 +20,7 @@ class Base(models.Model):
         (DELETED, 'Deleted'),
     ]
 
-    claims_rules = JSONField(blank=True, null=True)
+    claims_rules = models.JSONField(blank=True, null=True)
     updated_at = models.DateTimeField(auto_now=True)
     created_at = models.DateTimeField(auto_now_add=True)
     updated_by = models.CharField(max_length=191, blank=True, null=True)
@@ -34,7 +35,11 @@ class Base(models.Model):
         verbose_name='Status',
         validators=[MinValueValidator(0), MaxValueValidator(3)],
     )
-    client = JSONField(blank=True, null=True)
+    client = models.JSONField(
+        blank=True,
+        null=True,
+        help_text=json.dumps(client_schema),
+    )
 
     class Meta:
         abstract = True
